Scripts rely on .env file with the required variables defined


Available functions:

- get_assets_by_layout_id(api_baseurl, api_key, asset_layout_id)
- create_magic_dash(api_baseurl, api_key, dash_name, dash_message, dash_shade, dash_content, company_name):

